#ifndef QLINEEDITSCALEDFONT_H
#define QLINEEDITSCALEDFONT_H

#include <QtGui>

class QLineEditScaledFont : public QLineEdit
{
    Q_OBJECT
public:
    explicit QLineEditScaledFont(QWidget *parent = 0);
    int padding;

private:
    virtual void resizeEvent(QResizeEvent *);
    //virtual void paintEvent(QPaintEvent *);
    QFontMetrics *fontMetrics;
    QTimer *timer;

private slots:
    void TimerTick();
    void StartTimer(int);
    void textChanged(QString);

signals:
    void resizeComplete();

};

#endif // QLINEEDITSCALEDFONT_H
